==> mono_1.1.12.1.orig.tar.gz: mono-1.1.12.1/mcs/class/System.Configuration/System.Configuration/KeyValueInternalCollection.cs <==
//
// System.Configuration.KeyValueInternalCollection.cs
//
// Authors:
//  Chris Toshok (toshok@ximian.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//

#if NET_2_0
using System.Collections.Specialized;
using System.Xml;

namespace System.Configuration
{
	internal class KeyValueInternalCollection: NameValueCollection
	{
		KeyValueConfigurationCollection col;

		public KeyValueInternalCollection ()
		{
			col = new KeyValueConfigurationCollection ();
		}

		
		public void SetReadOnly ()
		{
			col.SetReadOnly ();
		}

		public override void Add (string name, string val)
		{
			col.Add (new KeyValueConfigurationElement (name, val));
		}

		public override void Remove (string name)
		{
			col.Remove (name);
		}

		public override string[] AllKeys
		{
			get {
				return col.AllKeys;
			}
		}

		public override string Get (string name)
		{
			KeyValueConfigurationElement ele = col[name];
			if (ele != null)
				return ele.Value;

			return null;
		}

			/*

		public virtual string Get( int index )
		public virtual string GetKey( int index )
		public virtual string[] GetValues( int index )
		public virtual string[] GetValues( string name )
		public virtual void Set (string name, string value)

			*/

	}
}
#endif

==> mono-1.1.15.tar.gz: mono-1.1.15/mcs/class/System.Configuration/System.Configuration/KeyValueInternalCollection.cs <==
//
// System.Configuration.KeyValueInternalCollection.cs
//
// Authors:
//  Chris Toshok (toshok@ximian.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//

#if NET_2_0
using System.Collections.Specialized;
using System.Xml;

namespace System.Configuration
{
	internal class KeyValueInternalCollection: NameValueCollection
	{
		public void SetReadOnly ()
		{
			base.IsReadOnly  = true;
		}

		public override void Add (string name, string val)
		{
			BaseAdd (name, val);
		}

		public override void Remove (string name)
		{
			BaseRemove (name);
		}

		public override string[] AllKeys {
			get { return BaseGetAllKeys (); }
		}

		public override string Get (string name)
		{
			return (string)BaseGet (name);
		}

			/*

		public virtual string Get( int index )
		public virtual string GetKey( int index )
		public virtual string[] GetValues( int index )
		public virtual string[] GetValues( string name )
		public virtual void Set (string name, string value)

			*/

	}
}
#endif
